@@ -21,10 +21,7 @@ import Gio from "gi://Gio";
 import Adw from "gi://Adw";
 import GObject from "gi://GObject";
 
-import {
-    ExtensionPreferences,
-    gettext as _,
-} from "resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js";
+import { ExtensionPreferences, gettext as _ } from "resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js";
 
 const keyvalIsForbidden$1 = (keyval) => {
     return [
@@ -44,10 +41,7 @@ const keyvalIsForbidden$1 = (keyval) => {
 };
 
 const isValidAccel$1 = (mask, keyval) => {
-    return (
-        Gtk.accelerator_valid(keyval, mask) ||
-        (keyval === Gdk.KEY_Tab && mask !== 0)
-    );
+    return Gtk.accelerator_valid(keyval, mask) || (keyval === Gdk.KEY_Tab && mask !== 0);
 };
 
 // eslint-disable-next-line complexity
@@ -59,20 +53,13 @@ const isValidBinding$1 = (mask, keycode, keyval) => {
             ((keyval >= Gdk.KEY_a && keyval <= Gdk.KEY_z) ||
                 (keyval >= Gdk.KEY_A && keyval <= Gdk.KEY_Z) ||
                 (keyval >= Gdk.KEY_0 && keyval <= Gdk.KEY_9) ||
-                (keyval >= Gdk.KEY_kana_fullstop &&
-                    keyval <= Gdk.KEY_semivoicedsound) ||
-                (keyval >= Gdk.KEY_Arabic_comma &&
-                    keyval <= Gdk.KEY_Arabic_sukun) ||
-                (keyval >= Gdk.KEY_Serbian_dje &&
-                    keyval <= Gdk.KEY_Cyrillic_HARDSIGN) ||
-                (keyval >= Gdk.KEY_Greek_ALPHAaccent &&
-                    keyval <= Gdk.KEY_Greek_omega) ||
-                (keyval >= Gdk.KEY_hebrew_doublelowline &&
-                    keyval <= Gdk.KEY_hebrew_taf) ||
-                (keyval >= Gdk.KEY_Thai_kokai &&
-                    keyval <= Gdk.KEY_Thai_lekkao) ||
-                (keyval >= Gdk.KEY_Hangul_Kiyeog &&
-                    keyval <= Gdk.KEY_Hangul_J_YeorinHieuh) ||
+                (keyval >= Gdk.KEY_kana_fullstop && keyval <= Gdk.KEY_semivoicedsound) ||
+                (keyval >= Gdk.KEY_Arabic_comma && keyval <= Gdk.KEY_Arabic_sukun) ||
+                (keyval >= Gdk.KEY_Serbian_dje && keyval <= Gdk.KEY_Cyrillic_HARDSIGN) ||
+                (keyval >= Gdk.KEY_Greek_ALPHAaccent && keyval <= Gdk.KEY_Greek_omega) ||
+                (keyval >= Gdk.KEY_hebrew_doublelowline && keyval <= Gdk.KEY_hebrew_taf) ||
+                (keyval >= Gdk.KEY_Thai_kokai && keyval <= Gdk.KEY_Thai_lekkao) ||
+                (keyval >= Gdk.KEY_Hangul_Kiyeog && keyval <= Gdk.KEY_Hangul_J_YeorinHieuh) ||
                 (keyval === Gdk.KEY_space && mask === 0) ||
                 keyvalIsForbidden$1(keyval)))
     );
@@ -104,8 +91,8 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
         if (response !== Gtk.ResponseType.ACCEPT) {
             return;
         }
-        let fileURI = native.get_file().get_uri();
-        let fileURI2 = fileURI.replace("file://", "");
+        const fileURI = native.get_file().get_uri();
+        const fileURI2 = fileURI.replace("file://", "");
         this.getSettings().set_string("shortcuts-file", fileURI2);
     }
 
@@ -123,37 +110,25 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
         group1.set_name("shortcuts_group1");
         page1.add(group1);
 
-        let expadwrow = new Adw.ExpanderRow({
+        const expadwrow = new Adw.ExpanderRow({
             title: _("Custom Shortcuts File"),
             subtitle: _("Use an alternative file for shortcut descriptions"),
         }); //row1
         expadwrow.set_tooltip_text(
-            _(
-                "If true the shortcut file specified as shortcuts-file will be used for custom shortcuts."
-            )
+            _("If true the shortcut file specified as shortcuts-file will be used for custom shortcuts.")
         );
         group1.add(expadwrow);
         const togglecustomfile = new Gtk.Switch({
             active: window._settings.get_boolean("use-custom-shortcuts"),
             valign: Gtk.Align.CENTER,
         });
-        window._settings.bind(
-            "use-custom-shortcuts",
-            togglecustomfile,
-            "active",
-            Gio.SettingsBindFlags.DEFAULT
-        );
+        window._settings.bind("use-custom-shortcuts", togglecustomfile, "active", Gio.SettingsBindFlags.DEFAULT);
 
         expadwrow.set_expanded(togglecustomfile.get_active());
         expadwrow.add_suffix(togglecustomfile);
         expadwrow.activatable_widget = togglecustomfile;
 
-        togglecustomfile.bind_property(
-            "active",
-            expadwrow,
-            "expanded",
-            GObject.BindingFlags.DEFAULT
-        );
+        togglecustomfile.bind_property("active", expadwrow, "expanded", GObject.BindingFlags.DEFAULT);
 
         adwrow = new Adw.ActionRow({
             title: "-",
@@ -161,27 +136,21 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
         }); //row2
         expadwrow.add_row(adwrow);
         this._updateshortcutsfile(adwrow);
-        window._settings.connect(
-            "changed::shortcuts-file",
-            this._updateshortcutsfile.bind(this, adwrow)
-        );
+        window._settings.connect("changed::shortcuts-file", this._updateshortcutsfile.bind(this, adwrow));
 
         adwrow = new Adw.ActionRow({ title: _("Select shortcut file") }); //row3
         adwrow.set_tooltip_text(_("Select shortcut file"));
-        let buttonfilechooser = new Gtk.Button({
+        const buttonfilechooser = new Gtk.Button({
             label: _("..."),
             valign: Gtk.Align.CENTER,
         });
 
-        let filechooser = new Gtk.FileChooserNative({
+        const filechooser = new Gtk.FileChooserNative({
             title: _("Select shortcut file"),
             modal: true,
             action: Gtk.FileChooserAction.OPEN,
         });
-        buttonfilechooser.connect(
-            "clicked",
-            this._onBtnClicked.bind(this, buttonfilechooser, filechooser)
-        );
+        buttonfilechooser.connect("clicked", this._onBtnClicked.bind(this, buttonfilechooser, filechooser));
         filechooser.connect("response", this._onFileChooserResponse.bind(this));
         adwrow.add_suffix(buttonfilechooser);
         adwrow.activatable_widget = buttonfilechooser;
@@ -194,12 +163,7 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
                 "If enabled the extension searches for an appname.json (appname is the app which has focus) in ~/.config/Shortcuts@kyle.aims.ac.za and /etc/Shortcuts@kyle.aims.ac.za. Default file is shown when no appname.json is available. appname.json files are not shipped and the users responsibility!"
             )
         );
-        window._settings.bind(
-            "enable-appspecific-files",
-            adwrow,
-            "active",
-            Gio.SettingsBindFlags.DEFAULT
-        );
+        window._settings.bind("enable-appspecific-files", adwrow, "active", Gio.SettingsBindFlags.DEFAULT);
         group1.add(adwrow);
         const group2 = Adw.PreferencesGroup.new(); //group2
         group2.set_title(_("Appearance"));
@@ -208,43 +172,24 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
         adwrow = this._adwSwitchrow(
             _("Show icon"),
             _("Toggles the icon on the top panel"),
-            _(
-                "If true an icon to activate the extension will be visible on the top panel."
-            )
-        );
-        window._settings.bind(
-            "show-icon",
-            adwrow,
-            "active",
-            Gio.SettingsBindFlags.DEFAULT
+            _("If true an icon to activate the extension will be visible on the top panel.")
         );
+        window._settings.bind("show-icon", adwrow, "active", Gio.SettingsBindFlags.DEFAULT);
         group2.add(adwrow);
         adwrow = this._adwSwitchrow(
             _("Use transparency"),
             _("Toggles the transparency on the shortcuts dialog"),
             _("If true transparency will be applied to the shortcuts dialog.")
         );
-        window._settings.bind(
-            "use-transparency",
-            adwrow,
-            "active",
-            Gio.SettingsBindFlags.DEFAULT
-        );
+        window._settings.bind("use-transparency", adwrow, "active", Gio.SettingsBindFlags.DEFAULT);
         group2.add(adwrow);
         adwrow = this._adwSpinRow(
             _("Visibility"),
             _("Visibility in percent"),
-            _(
-                "Visibility - values between 0 and 100 are allowed (0 invisible)"
-            ),
+            _("Visibility - values between 0 and 100 are allowed (0 invisible)"),
             [0, 100, 1, 10]
         );
-        window._settings.bind(
-            "visibility",
-            adwrow,
-            "value",
-            Gio.SettingsBindFlags.DEFAULT
-        );
+        window._settings.bind("visibility", adwrow, "value", Gio.SettingsBindFlags.DEFAULT);
         group2.add(adwrow);
         adwrow = this._adwSpinRow(
             _("Max columns"),
@@ -252,12 +197,7 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
             _("Max count of columns inside main panel (2-5 are supported)"),
             [2, 5, 1, 1]
         );
-        window._settings.bind(
-            "maxcolumns",
-            adwrow,
-            "value",
-            Gio.SettingsBindFlags.DEFAULT
-        );
+        window._settings.bind("maxcolumns", adwrow, "value", Gio.SettingsBindFlags.DEFAULT);
         group2.add(adwrow);
         const group3 = Adw.PreferencesGroup.new(); //group8
         group3.set_title(_("Hotkey"));
@@ -267,22 +207,16 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
             title: _("Hotkey"),
             subtitle: _("Hotkey to toggle the shortcuts overview"),
         });
-        adwrow.set_tooltip_text(
-            _("Hotkey can be changed If Ctrl+Alt+Super+S is already used")
-        );
+        adwrow.set_tooltip_text(_("Hotkey can be changed If Ctrl+Alt+Super+S is already used"));
         //row7
         const shortcutLabel = new Gtk.ShortcutLabel({
             disabled_text: _("Select a hotkey"),
-            accelerator: window._settings.get_strv(
-                "shortcuts-toggle-overview"
-            )[0],
+            accelerator: window._settings.get_strv("shortcuts-toggle-overview")[0],
             valign: Gtk.Align.CENTER,
             halign: Gtk.Align.CENTER,
         });
         window._settings.connect("changed::shortcuts-toggle-overview", () => {
-            shortcutLabel.set_accelerator(
-                window._settings.get_strv("shortcuts-toggle-overview")[0]
-            );
+            shortcutLabel.set_accelerator(window._settings.get_strv("shortcuts-toggle-overview")[0]);
         });
         adwrow.connect("activated", () => {
             const ctl = new Gtk.EventControllerKey();
@@ -308,19 +242,11 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
                     editor.close();
                     return Gdk.EVENT_STOP;
                 }
-                if (
-                    !isValidBinding$1(mask, keycode, keyval) ||
-                    !isValidAccel$1(mask, keyval)
-                ) {
+                if (!isValidBinding$1(mask, keycode, keyval) || !isValidAccel$1(mask, keyval)) {
                     return Gdk.EVENT_STOP;
                 }
                 window._settings.set_strv("shortcuts-toggle-overview", [
-                    Gtk.accelerator_name_with_keycode(
-                        null,
-                        keyval,
-                        keycode,
-                        mask
-                    ),
+                    Gtk.accelerator_name_with_keycode(null, keyval, keycode, mask),
                 ]);
                 editor.destroy();
                 return Gdk.EVENT_STOP;
@@ -335,7 +261,7 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
     }
 
     _adwSwitchrow(strTitle, strSubtitle, strTooltip) {
-        let adwrow = new Adw.SwitchRow({
+        const adwrow = new Adw.SwitchRow({
             title: strTitle,
             subtitle: strSubtitle,
         });
@@ -343,8 +269,8 @@ export default class AdwShortcutsPrefsWidget extends ExtensionPreferences {
         return adwrow;
     }
     _adwSpinRow(strTitle, strSubtitle, strTooltip, values) {
-        let [min, max, step, climbrate] = values;
-        let adwrow = Adw.SpinRow.new_with_range(min, max, step);
+        const [min, max, step, climbrate] = values;
+        const adwrow = Adw.SpinRow.new_with_range(min, max, step);
         adwrow.set_title(strTitle);
         adwrow.set_subtitle(strSubtitle);
         adwrow.set_tooltip_text(strTooltip);
